% This case study demonstrates a simple (basic) setup of a single-period
% portfolio optimization problem when risk is measured by CVaR. 

clc
clear;

%Load the matrix matrix_prior_scenarios:
load('.\matrix_prior_scenarios.mat');

%Define problem statement:
problem_statement = sprintf('%s\n',...
'minimize',...
'  cvar_risk(0.95, matrix_prior_scenarios)',...
'Constraint: constraint_budget, == 1',...
'  linear(matrix_budget)',...
'Constraint: constraint_return, >= 0.00105',...
'  avg_g(matrix_prior_scenarios)',...
'Box: >= 0',...
'Solver: precision = 3');

% Pack the matrix of scenarios:
toolboxstruc_arr(1) = tbpsg_matrix_pack('matrix_prior_scenarios',matrix_prior_scenarios_arr,header_matrix_prior_scenarios);

%Define the matrix matrix_budget:
header_matrix_budget = {'x1',   'x2',   'x3',   'x4',   'scenario_probability', 'scenario_benchmark'};
matrix_budget = [1   1   1   1   1   0];

%Pack the matrix of budget constraints:
toolboxstruc_arr(2) = tbpsg_matrix_pack('matrix_budget',matrix_budget,header_matrix_budget);

%Set point "point_lowerbounds":
header_point_lowerbounds = {'x1'    'x2'    'x3'    'x4'};
point_lowerbounds = [0 0 0 0];

%Pack the lowerbound point:
toolboxstruc_arr(3) = tbpsg_point_pack('point_lowerbounds',point_lowerbounds,header_point_lowerbounds);

% Uncomment the following line to open the problem in Toolbox Window
% tbpsg_toolbox(problem_statement,toolboxstruc_arr);

%Optimize problem:
[solution_str, outargstruc_arr] = tbpsg_run(problem_statement, toolboxstruc_arr);

%Get times
time = tbpsg_time(solution_str, outargstruc_arr);

fprintf('Loading time: %f\nPreprocessing time: %f\nSolving time: %f\n', time(1), time(2), time(3));
disp(' ')
disp(' Solution Report')
disp(solution_str)

%=======================================================================|
%American Optimal Decisions, Inc. Copyright                             |
%Copyright American Optimal Decisions, Inc. 2007-2016.                 |
%American Optimal Decisions (AOD) retains copyrights to this material.  |
%                                                                       |
%Permission to reproduce this document and to prepare derivative works  |
%from this document for internal use is granted, provided the copyright |
%and No Warranty  statements are included with all reproductions       |
%and derivative works.                                                  |
%                                                                       |
%For information regarding external or commercial use of copyrighted    |
%materials owned by AOD, contact AOD at support@aorda.com.              |
%=======================================================================|
